SystemOrganization addCategory: #ConfigurationOfCoExist!

Object subclass: #ConfigurationOfCoExist
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfCoExist'!

!ConfigurationOfCoExist commentStamp: '<historical>' prior: 0!
Copy me to create a new configuration or edit and evaluate the following doits.

        "Create configuration class and initial baseline method"

        MetacelloToolBox 
                createBaseline: '1.0-baseline'
                for: 'MyProject'
                repository: 'http://www.example.com/MyProjectRepository'
                requiredProjects: #('Gofer')
                packages: #('MyProject-Core' 'MyProject-Tests')
                dependencies:
                        {('MyProject-Core' -> #('Gofer')).
                         ('MyProject-Tests' -> #('MyProject-Core'))}
                groups:
                        {('default' -> #('Core')).
                        ('Core' -> #('MyProject-Core')).
                        ('Tests' -> #('MyProject-Tests'))}.

	   "create initial development method from the baseline"

         MetacelloToolBox
               createDevelopment: '1.0'
               for: 'MyProject'
                importFromBaseline: '1.0-baseline'
                description: 'initial version'.
!

!ConfigurationOfCoExist class methodsFor: 'development support' stamp: 'mt 7/16/2013 11:10:39.146'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfCoExist class methodsFor: 'private' stamp: 'mt 7/16/2013 11:10:39.318'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfCoExist class methodsFor: 'private' stamp: 'mt 7/16/2013 11:10:39.404'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfCoExist class methodsFor: 'private' stamp: 'sp 7/18/2013 14:36:57.762'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemtalksystems.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfCoExist class methodsFor: 'as yet unclassified' stamp: 'mt 7/19/2013 14:37:50.064'!
ensureRepositoryAccessFor: spec

	| privatePackages loginData |
	privatePackages := spec.
	loginData := Dictionary new.
		
	privatePackages keysAndValuesDo: [:packageName :location |
		| repository addDefault |
		addDefault := false.
		"Try to find the repository in the corresponding package."
		repository := (MCPackage named: packageName) workingCopy repositoryGroup in: [:group |
			group repositories
				detect: [:repo | repo description endsWith: location second]
				ifNone: []].
		"Try to find the repository in the default group."
		repository ifNil: [repository := (MCRepositoryGroup default repositories
			detect: [:repo | repo description endsWith: location second]
			ifNone: []) ifNotNil: [:r | addDefault := true. r]].
		
		"Create a new one if still not found."
		repository ifNil: [
			loginData at: location first ifAbsentPut: [
					(UIManager default request: 'User (', location first, ')')
						-> (UIManager default requestPassword: 'Password (', location first, ')')].
			repository := MCHttpRepository
					location: location first, location second
					user: (loginData at: location first) key
					password: (loginData at: location first) value.
			addDefault := true].
			
		addDefault ifTrue: [
			(MCPackage named: packageName) workingCopy repositoryGroup addRepository: repository]].! !

!ConfigurationOfCoExist class methodsFor: 'metacello tool support' stamp: 'mt 7/16/2013 11:10:39.576'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfCoExist class methodsFor: 'loading' stamp: 'mt 7/16/2013 11:10:39.661'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfCoExist class methodsFor: 'loading' stamp: 'mt 7/16/2013 11:10:39.746'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfCoExist class methodsFor: 'loading' stamp: 'mt 7/16/2013 11:10:39.832'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfCoExist class methodsFor: 'accessing' stamp: 'mt 7/18/2013 17:45:15.773'!
project

	^self new project! !

!ConfigurationOfCoExist class methodsFor: 'development support' stamp: 'mt 7/16/2013 11:10:39.232'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfCoExist methodsFor: 'baselines' stamp: 'sp 9/23/2013 15:19:35.926'!
baseline100: spec
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/ContiuousVersioning'.
		
		spec project: 'OmniBrowser' with: [
			spec
				className: 'ConfigurationOfOmniBrowser';
				loads: #('Core RB' 'OB-SUnitIntegration' 'OB-Shout');
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
			
		spec project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					loads: #('Core')].
		
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'LateClassBinding' with: [
			spec
				className: 'ConfigurationOfLateClassBinding';
				loads: #('core');
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'OB-LateClassBinding' with: [
			spec
				className: 'ConfigurationOfLateClassBinding';
				loads: #('ob');
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
		
		spec project: 'SwaUtil' with: [
			spec
				className: 'ConfigurationOfSwaUtil';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				loads: #('core');
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
		spec project: 'WidgetsTools' with: [
			spec
				className: 'ConfigurationOfWidgets';
				loads: #('tools');
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
		
		spec package: 'Icons' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].
		
		spec
			package: 'PolySource' with: [spec
				requires: #('Signals' 'Icons' 'LateClassBinding');
				preLoadDoIt: #preLoad];
			package: 'CV-TestBed' with: [spec
				requires: #('PolySource' 'Widgets' 'Icons' 'Refactoring-Core' 'OmniBrowser' 'OB-LateClassBinding' 'SwaUtil')];
			package: 'CV-Core' with: [spec
				requires: #('CV-TestBed');
				preLoadDoIt: #preLoad;  
				postLoadDoIt: #postLoad];
			package: 'CV-UI' with: [spec
				requires: #('CV-Core' 'WidgetsTools');
				postLoadDoIt: #uiPostLoad].
			
		spec
			group: 'default' with: #('ui');
			group: 'core' with: #('CV-Core');
			group: 'ui' with: #('CV-UI').
		].! !

!ConfigurationOfCoExist methodsFor: 'accessing' stamp: 'mt 7/16/2013 11:10:38.975'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfCoExist methodsFor: 'symbolic versions' stamp: 'mt 7/16/2013 14:15:38.544'!
development: spec 
	<symbolicVersion: #development>
	
	spec for: #'common' version: '2.0.0'.! !

!ConfigurationOfCoExist methodsFor: 'initialize-release' stamp: 'sp 9/23/2013 13:33:28.325'!
initialize

	super initialize.
	
	self class ensureRepositoryAccessFor: (Dictionary newFrom: {
		#'PolySource' -> #('http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/' 'ContiuousVersioning').
		#'CV-TestBed' -> #('http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/' 'ContiuousVersioning').
		#'CV-Core' -> #('http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/' 'ContiuousVersioning').
		#'CV-UI' -> #('http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/' 'ContiuousVersioning')}).! !

!ConfigurationOfCoExist methodsFor: 'pre-/postload' stamp: 'sp 7/18/2013 16:27:29.14'!
postLoad

	Transcript cr; show: '[CoExist] Recompiling PolySource...'.
	(PackageInfo named: #PolySource) actualMethodsDo: [:method |
		method methodClass recompile: method selector].

	Transcript cr; show: '[CoExist] Recompiling ClassBuilder>>#validateClassName:...'.
	ClassBuilder recompile: #validateClassName:.
	
	Transcript cr; show: '[CoExist] Recompiling System...'.
	(PackageInfo named: #System) actualMethodsDo: [:method |
		method methodClass recompile: method selector].! !

!ConfigurationOfCoExist methodsFor: 'pre-/postload' stamp: 'mt 7/19/2013 15:11:37.15'!
preLoad

	(Object class instVarNames includes: #cvOriginal)
		ifFalse: [Object class addInstVarName: #cvOriginal].
	
	(Process instVarNames includes: #activeCodeBase)
		ifFalse: [Process addInstVarName: #activeCodeBase].! !

!ConfigurationOfCoExist methodsFor: 'accessing' stamp: 'mt 7/16/2013 11:10:39.06'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfCoExist methodsFor: 'symbolic versions' stamp: 'sp 9/23/2013 13:36:18.829'!
stable: spec 
	<symbolicVersion: #stable>
	
	"squeak 4.4"
	spec for: #'squeak4.x' version: '1.0.2'.! !

!ConfigurationOfCoExist methodsFor: 'pre-/postload' stamp: 'sp 9/23/2013 13:45:36.395'!
uiPostLoad

	UiWorldToolbar addButtons: {CvController cvToggleButtonDefinitions}! !

!ConfigurationOfCoExist methodsFor: 'versions' stamp: 'mt 7/16/2013 16:04:30.219'!
version100: spec
	<version: '1.0.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Stephi Platz'.
		
		spec
			project: 'OmniBrowser' with: '1.2.4.1';
			project: 'Refactoring-Core' with: '2.0.2';
			project: 'Signals' with: '1.0.8';
			project: 'LateClassBinding' with: '1.0.0';
			project: 'OB-LateClassBinding' with: '1.0.0';
			project: 'SwaUtil' with: '1.1.5';
			project: 'Widgets' with: '1.1.4'.
		
		spec
			package: 'Icons' with: 'Icons-mt.3';
			package: 'PolySource' with: 'PolySource-sp.158';
			package: 'CV' with: 'CV-sp.107'.]! !

!ConfigurationOfCoExist methodsFor: 'versions' stamp: 'sp 7/18/2013 14:10:29.193'!
version101: spec
	<version: '1.0.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Stephi Platz'.
		
		spec
			project: 'OmniBrowser' with: '1.2.4.1';
			project: 'Refactoring-Core' with: '2.0.2';
			project: 'Signals' with: '1.0.8';
			project: 'LateClassBinding' with: '1.0.1';
			project: 'OB-LateClassBinding' with: '1.0.1';
			project: 'SwaUtil' with: '1.1.5';
			project: 'Widgets' with: '1.1.4'.
		
		spec
			package: 'Icons' with: 'Icons-mt.3';
			package: 'PolySource' with: 'PolySource-mt.159';
			package: 'CV' with: 'CV-sp.107'.]! !

!ConfigurationOfCoExist methodsFor: 'versions' stamp: 'sp 9/23/2013 14:12:25.997'!
version102: spec
	<version: '1.0.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Stephi Platz'.
		
		spec
			project: 'OmniBrowser' with: '1.2.4.1';
			project: 'Refactoring-Core' with: '2.0.2';
			project: 'Signals' with: '1.0.8';
			project: 'LateClassBinding' with: '1.0.2';
			project: 'OB-LateClassBinding' with: '1.0.1';
			project: 'SwaUtil' with: '1.1.5';
			project: 'Widgets' with: '1.1.4';
			project: 'WidgetsTools' with: '1.1.4'.
		
		spec
			package: 'Icons' with: 'Icons-mt.3';
			package: 'PolySource' with: 'PolySource-sp.161';
			package: 'CV-Core' with: 'CV-Core-sp.115';
			package: 'CV-UI' with: 'CV-UI-sp.2';
			package: 'CV-TestBed-sp.17']! !

!ConfigurationOfCoExist methodsFor: 'versions' stamp: 'mt 7/16/2013 16:04:41.984'!
version200: spec
	<version: '2.0.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Stephi Platz'.
		
		spec
			project: 'OmniBrowser' with: #stable;
			project: 'Refactoring-Core' with: #stable;
			project: 'Signals' with: #stable;
			project: 'LateClassBinding' with: #development;
			project: 'OB-LateClassBinding' with: #development;
			project: 'SwaUtil' with: #development;
			project: 'Widgets' with: #development.
		
	"	spec
			package: 'Icons' with: 'Icon-mt.3';
			package: 'PolySource' with: 'PolySource-sp.158';
			package: 'CV' with: 'CV-sp.107'."]! !
